@@ -2,7 +2,7 @@
 from collections.abc import Callable
 from typing import Any
 
-from homeassistant.components.logbook.const import (
+from homeassistant.components.logbook import (
     LOGBOOK_ENTRY_ENTITY_ID,
     LOGBOOK_ENTRY_MESSAGE,
     LOGBOOK_ENTRY_NAME,
