@@ -40,7 +40,7 @@ from homeassistant.const import (
 from homeassistant.core import Event, HomeAssistant, State, callback, split_entity_id
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.storage import STORAGE_DIR
-import homeassistant.util.temperature as temp_util
+from homeassistant.util.unit_conversion import TemperatureConverter
 
 from .const import (
     AUDIO_CODEC_COPY,
@@ -391,25 +391,25 @@ def cleanup_name_for_homekit(name: str | None) -> str:
 
 def temperature_to_homekit(temperature: float | int, unit: str) -> float:
     """Convert temperature to Celsius for HomeKit."""
-    return round(temp_util.convert(temperature, unit, TEMP_CELSIUS), 1)
+    return round(TemperatureConverter.convert(temperature, unit, TEMP_CELSIUS), 1)
 
 
 def temperature_to_states(temperature: float | int, unit: str) -> float:
     """Convert temperature back from Celsius to Home Assistant unit."""
-    return round(temp_util.convert(temperature, TEMP_CELSIUS, unit) * 2) / 2
+    return round(TemperatureConverter.convert(temperature, TEMP_CELSIUS, unit) * 2) / 2
 
 
 def density_to_air_quality(density: float) -> int:
-    """Map PM2.5 density to HomeKit AirQuality level."""
-    if density <= 35:
+    """Map PM2.5 µg/m3 density to HomeKit AirQuality level."""
+    if density <= 12:  # US AQI 0-50 (HomeKit: Excellent)
         return 1
-    if density <= 75:
+    if density <= 35.4:  # US AQI 51-100 (HomeKit: Good)
         return 2
-    if density <= 115:
+    if density <= 55.4:  # US AQI 101-150 (HomeKit: Fair)
         return 3
-    if density <= 150:
+    if density <= 150.4:  # US AQI 151-200 (HomeKit: Inferior)
         return 4
-    return 5
+    return 5  # US AQI 201+ (HomeKit: Poor)
 
 
 def density_to_air_quality_pm10(density: float) -> int:
@@ -425,19 +425,6 @@ def density_to_air_quality_pm10(density: float) -> int:
     return 5
 
 
-def density_to_air_quality_pm25(density: float) -> int:
-    """Map PM2.5 density to HomeKit AirQuality level."""
-    if density <= 25:
-        return 1
-    if density <= 50:
-        return 2
-    if density <= 100:
-        return 3
-    if density <= 300:
-        return 4
-    return 5
-
-
 def get_persist_filename_for_entry_id(entry_id: str) -> str:
     """Determine the filename of the homekit state file."""
     return f"{DOMAIN}.{entry_id}.state"
