@@ -8,8 +8,7 @@ from typing import Any
 import voluptuous as vol
 
 from homeassistant.components import climate
-from homeassistant.components.climate import ClimateEntity
-from homeassistant.components.climate.const import (
+from homeassistant.components.climate import (
     ATTR_HVAC_MODE,
     ATTR_TARGET_TEMP_HIGH,
     ATTR_TARGET_TEMP_LOW,
@@ -19,10 +18,10 @@ from homeassistant.components.climate.const import (
     FAN_HIGH,
     FAN_LOW,
     FAN_MEDIUM,
-    PRESET_AWAY,
     PRESET_NONE,
     SWING_OFF,
     SWING_ON,
+    ClimateEntity,
     ClimateEntityFeature,
     HVACAction,
     HVACMode,
@@ -51,7 +50,6 @@ from .debug_info import log_messages
 from .mixins import (
     MQTT_ENTITY_COMMON_SCHEMA,
     MqttEntity,
-    async_discover_yaml_entities,
     async_setup_entry_helper,
     async_setup_platform_helper,
     warn_for_legacy_schema,
@@ -68,10 +66,11 @@ CONF_ACTION_TOPIC = "action_topic"
 CONF_AUX_COMMAND_TOPIC = "aux_command_topic"
 CONF_AUX_STATE_TEMPLATE = "aux_state_template"
 CONF_AUX_STATE_TOPIC = "aux_state_topic"
-# AWAY and HOLD mode topics and templates are deprecated, support will be removed with release 2022.9
+# AWAY and HOLD mode topics and templates are no longer supported, support was removed with release 2022.9
 CONF_AWAY_MODE_COMMAND_TOPIC = "away_mode_command_topic"
 CONF_AWAY_MODE_STATE_TEMPLATE = "away_mode_state_template"
 CONF_AWAY_MODE_STATE_TOPIC = "away_mode_state_topic"
+
 CONF_CURRENT_TEMP_TEMPLATE = "current_temperature_template"
 CONF_CURRENT_TEMP_TOPIC = "current_temperature_topic"
 CONF_FAN_MODE_COMMAND_TEMPLATE = "fan_mode_command_template"
@@ -79,12 +78,13 @@ CONF_FAN_MODE_COMMAND_TOPIC = "fan_mode_command_topic"
 CONF_FAN_MODE_LIST = "fan_modes"
 CONF_FAN_MODE_STATE_TEMPLATE = "fan_mode_state_template"
 CONF_FAN_MODE_STATE_TOPIC = "fan_mode_state_topic"
-# AWAY and HOLD mode topics and templates are deprecated, support will be removed with release 2022.9
+# AWAY and HOLD mode topics and templates are no longer supported, support was removed with release 2022.9
 CONF_HOLD_COMMAND_TEMPLATE = "hold_command_template"
 CONF_HOLD_COMMAND_TOPIC = "hold_command_topic"
 CONF_HOLD_STATE_TEMPLATE = "hold_state_template"
 CONF_HOLD_STATE_TOPIC = "hold_state_topic"
 CONF_HOLD_LIST = "hold_modes"
+
 CONF_MODE_COMMAND_TEMPLATE = "mode_command_template"
 CONF_MODE_COMMAND_TOPIC = "mode_command_topic"
 CONF_MODE_LIST = "modes"
@@ -99,7 +99,7 @@ CONF_PRESET_MODE_COMMAND_TOPIC = "preset_mode_command_topic"
 CONF_PRESET_MODE_VALUE_TEMPLATE = "preset_mode_value_template"
 CONF_PRESET_MODE_COMMAND_TEMPLATE = "preset_mode_command_template"
 CONF_PRESET_MODES_LIST = "preset_modes"
-# CONF_SEND_IF_OFF is deprecated, support will be removed with release 2022.9
+# Support CONF_SEND_IF_OFF is removed with release 2022.9
 CONF_SEND_IF_OFF = "send_if_off"
 CONF_SWING_MODE_COMMAND_TEMPLATE = "swing_mode_command_template"
 CONF_SWING_MODE_COMMAND_TOPIC = "swing_mode_command_topic"
@@ -150,12 +150,8 @@ MQTT_CLIMATE_ATTRIBUTES_BLOCKED = frozenset(
 
 VALUE_TEMPLATE_KEYS = (
     CONF_AUX_STATE_TEMPLATE,
-    # AWAY and HOLD mode topics and templates are deprecated, support will be removed with release 2022.9
-    CONF_AWAY_MODE_STATE_TEMPLATE,
     CONF_CURRENT_TEMP_TEMPLATE,
     CONF_FAN_MODE_STATE_TEMPLATE,
-    # AWAY and HOLD mode topics and templates are deprecated, support will be removed with release 2022.9
-    CONF_HOLD_STATE_TEMPLATE,
     CONF_MODE_STATE_TEMPLATE,
     CONF_POWER_STATE_TEMPLATE,
     CONF_ACTION_TEMPLATE,
@@ -168,8 +164,6 @@ VALUE_TEMPLATE_KEYS = (
 
 COMMAND_TEMPLATE_KEYS = {
     CONF_FAN_MODE_COMMAND_TEMPLATE,
-    # AWAY and HOLD mode topics and templates are deprecated, support will be removed with release 2022.9
-    CONF_HOLD_COMMAND_TEMPLATE,
     CONF_MODE_COMMAND_TEMPLATE,
     CONF_PRESET_MODE_COMMAND_TEMPLATE,
     CONF_SWING_MODE_COMMAND_TEMPLATE,
@@ -178,32 +172,14 @@ COMMAND_TEMPLATE_KEYS = {
     CONF_TEMP_LOW_COMMAND_TEMPLATE,
 }
 
-# AWAY and HOLD mode topics and templates are deprecated, support will be removed with release 2022.9
-DEPRECATED_INVALID = [
-    CONF_AWAY_MODE_COMMAND_TOPIC,
-    CONF_AWAY_MODE_STATE_TEMPLATE,
-    CONF_AWAY_MODE_STATE_TOPIC,
-    CONF_HOLD_COMMAND_TEMPLATE,
-    CONF_HOLD_COMMAND_TOPIC,
-    CONF_HOLD_STATE_TEMPLATE,
-    CONF_HOLD_STATE_TOPIC,
-    CONF_HOLD_LIST,
-]
-
 
 TOPIC_KEYS = (
     CONF_ACTION_TOPIC,
     CONF_AUX_COMMAND_TOPIC,
     CONF_AUX_STATE_TOPIC,
-    # AWAY and HOLD mode topics and templates are deprecated, support will be removed with release 2022.9
-    CONF_AWAY_MODE_COMMAND_TOPIC,
-    CONF_AWAY_MODE_STATE_TOPIC,
     CONF_CURRENT_TEMP_TOPIC,
     CONF_FAN_MODE_COMMAND_TOPIC,
     CONF_FAN_MODE_STATE_TOPIC,
-    # AWAY and HOLD mode topics and templates are deprecated, support will be removed with release 2022.9
-    CONF_HOLD_COMMAND_TOPIC,
-    CONF_HOLD_STATE_TOPIC,
     CONF_MODE_COMMAND_TOPIC,
     CONF_MODE_STATE_TOPIC,
     CONF_POWER_COMMAND_TOPIC,
@@ -225,12 +201,6 @@ def valid_preset_mode_configuration(config):
     """Validate that the preset mode reset payload is not one of the preset modes."""
     if PRESET_NONE in config.get(CONF_PRESET_MODES_LIST):
         raise ValueError("preset_modes must not include preset mode 'none'")
-    if config.get(CONF_PRESET_MODE_COMMAND_TOPIC):
-        for config_parameter in DEPRECATED_INVALID:
-            if config.get(config_parameter):
-                raise vol.MultipleInvalid(
-                    "preset_modes cannot be used with deprecated away or hold mode config options"
-                )
     return config
 
 
@@ -239,10 +209,6 @@ _PLATFORM_SCHEMA_BASE = MQTT_BASE_SCHEMA.extend(
         vol.Optional(CONF_AUX_COMMAND_TOPIC): valid_publish_topic,
         vol.Optional(CONF_AUX_STATE_TEMPLATE): cv.template,
         vol.Optional(CONF_AUX_STATE_TOPIC): valid_subscribe_topic,
-        # AWAY and HOLD mode topics and templates are deprecated, support will be removed with release 2022.9
-        vol.Optional(CONF_AWAY_MODE_COMMAND_TOPIC): valid_publish_topic,
-        vol.Optional(CONF_AWAY_MODE_STATE_TEMPLATE): cv.template,
-        vol.Optional(CONF_AWAY_MODE_STATE_TOPIC): valid_subscribe_topic,
         vol.Optional(CONF_CURRENT_TEMP_TEMPLATE): cv.template,
         vol.Optional(CONF_CURRENT_TEMP_TOPIC): valid_subscribe_topic,
         vol.Optional(CONF_FAN_MODE_COMMAND_TEMPLATE): cv.template,
@@ -253,12 +219,6 @@ _PLATFORM_SCHEMA_BASE = MQTT_BASE_SCHEMA.extend(
         ): cv.ensure_list,
         vol.Optional(CONF_FAN_MODE_STATE_TEMPLATE): cv.template,
         vol.Optional(CONF_FAN_MODE_STATE_TOPIC): valid_subscribe_topic,
-        # AWAY and HOLD mode topics and templates are deprecated, support will be removed with release 2022.9
-        vol.Optional(CONF_HOLD_COMMAND_TEMPLATE): cv.template,
-        vol.Optional(CONF_HOLD_COMMAND_TOPIC): valid_publish_topic,
-        vol.Optional(CONF_HOLD_STATE_TEMPLATE): cv.template,
-        vol.Optional(CONF_HOLD_STATE_TOPIC): valid_subscribe_topic,
-        vol.Optional(CONF_HOLD_LIST): cv.ensure_list,
         vol.Optional(CONF_MODE_COMMAND_TEMPLATE): cv.template,
         vol.Optional(CONF_MODE_COMMAND_TOPIC): valid_publish_topic,
         vol.Optional(
@@ -284,8 +244,6 @@ _PLATFORM_SCHEMA_BASE = MQTT_BASE_SCHEMA.extend(
             [PRECISION_TENTHS, PRECISION_HALVES, PRECISION_WHOLE]
         ),
         vol.Optional(CONF_RETAIN, default=DEFAULT_RETAIN): cv.boolean,
-        # CONF_SEND_IF_OFF is deprecated, support will be removed with release 2022.9
-        vol.Optional(CONF_SEND_IF_OFF): cv.boolean,
         vol.Optional(CONF_ACTION_TEMPLATE): cv.template,
         vol.Optional(CONF_ACTION_TOPIC): valid_subscribe_topic,
         # CONF_PRESET_MODE_COMMAND_TOPIC and CONF_PRESET_MODES_LIST must be used together
@@ -327,6 +285,17 @@ _PLATFORM_SCHEMA_BASE = MQTT_BASE_SCHEMA.extend(
 ).extend(MQTT_ENTITY_COMMON_SCHEMA.schema)
 
 PLATFORM_SCHEMA_MODERN = vol.All(
+    # Support CONF_SEND_IF_OFF is removed with release 2022.9
+    cv.removed(CONF_SEND_IF_OFF),
+    # AWAY and HOLD mode topics and templates are no longer supported, support was removed with release 2022.9
+    cv.removed(CONF_AWAY_MODE_COMMAND_TOPIC),
+    cv.removed(CONF_AWAY_MODE_STATE_TEMPLATE),
+    cv.removed(CONF_AWAY_MODE_STATE_TOPIC),
+    cv.removed(CONF_HOLD_COMMAND_TEMPLATE),
+    cv.removed(CONF_HOLD_COMMAND_TOPIC),
+    cv.removed(CONF_HOLD_STATE_TEMPLATE),
+    cv.removed(CONF_HOLD_STATE_TOPIC),
+    cv.removed(CONF_HOLD_LIST),
     _PLATFORM_SCHEMA_BASE,
     valid_preset_mode_configuration,
 )
@@ -334,17 +303,6 @@ PLATFORM_SCHEMA_MODERN = vol.All(
 # Configuring MQTT Climate under the climate platform key is deprecated in HA Core 2022.6
 PLATFORM_SCHEMA = vol.All(
     cv.PLATFORM_SCHEMA.extend(_PLATFORM_SCHEMA_BASE.schema),
-    # CONF_SEND_IF_OFF is deprecated, support will be removed with release 2022.9
-    cv.deprecated(CONF_SEND_IF_OFF),
-    # AWAY and HOLD mode topics and templates are deprecated, support will be removed with release 2022.9
-    cv.deprecated(CONF_AWAY_MODE_COMMAND_TOPIC),
-    cv.deprecated(CONF_AWAY_MODE_STATE_TEMPLATE),
-    cv.deprecated(CONF_AWAY_MODE_STATE_TOPIC),
-    cv.deprecated(CONF_HOLD_COMMAND_TEMPLATE),
-    cv.deprecated(CONF_HOLD_COMMAND_TOPIC),
-    cv.deprecated(CONF_HOLD_STATE_TEMPLATE),
-    cv.deprecated(CONF_HOLD_STATE_TOPIC),
-    cv.deprecated(CONF_HOLD_LIST),
     valid_preset_mode_configuration,
     warn_for_legacy_schema(climate.DOMAIN),
 )
@@ -353,17 +311,17 @@ _DISCOVERY_SCHEMA_BASE = _PLATFORM_SCHEMA_BASE.extend({}, extra=vol.REMOVE_EXTRA
 
 DISCOVERY_SCHEMA = vol.All(
     _DISCOVERY_SCHEMA_BASE,
-    # CONF_SEND_IF_OFF is deprecated, support will be removed with release 2022.9
-    cv.deprecated(CONF_SEND_IF_OFF),
-    # AWAY and HOLD mode topics and templates are deprecated, support will be removed with release 2022.9
-    cv.deprecated(CONF_AWAY_MODE_COMMAND_TOPIC),
-    cv.deprecated(CONF_AWAY_MODE_STATE_TEMPLATE),
-    cv.deprecated(CONF_AWAY_MODE_STATE_TOPIC),
-    cv.deprecated(CONF_HOLD_COMMAND_TEMPLATE),
-    cv.deprecated(CONF_HOLD_COMMAND_TOPIC),
-    cv.deprecated(CONF_HOLD_STATE_TEMPLATE),
-    cv.deprecated(CONF_HOLD_STATE_TOPIC),
-    cv.deprecated(CONF_HOLD_LIST),
+    # Support CONF_SEND_IF_OFF is removed with release 2022.9
+    cv.removed(CONF_SEND_IF_OFF),
+    # AWAY and HOLD mode topics and templates are no longer supported, support was removed with release 2022.9
+    cv.removed(CONF_AWAY_MODE_COMMAND_TOPIC),
+    cv.removed(CONF_AWAY_MODE_STATE_TEMPLATE),
+    cv.removed(CONF_AWAY_MODE_STATE_TOPIC),
+    cv.removed(CONF_HOLD_COMMAND_TEMPLATE),
+    cv.removed(CONF_HOLD_COMMAND_TOPIC),
+    cv.removed(CONF_HOLD_STATE_TEMPLATE),
+    cv.removed(CONF_HOLD_STATE_TOPIC),
+    cv.removed(CONF_HOLD_LIST),
     valid_preset_mode_configuration,
 )
 
@@ -391,9 +349,6 @@ async def async_setup_entry(
     async_add_entities: AddEntitiesCallback,
 ) -> None:
     """Set up MQTT climate device through configuration.yaml and dynamically through MQTT discovery."""
-    # load and initialize platform config from configuration.yaml
-    await async_discover_yaml_entities(hass, climate.DOMAIN)
-    # setup for discovery
     setup = functools.partial(
         _async_setup_entity, hass, async_add_entities, config_entry=config_entry
     )
@@ -421,12 +376,10 @@ class MqttClimate(MqttEntity, ClimateEntity):
         """Initialize the climate device."""
         self._action = None
         self._aux = False
-        self._away = False
         self._current_fan_mode = None
         self._current_operation = None
         self._current_swing_mode = None
         self._current_temp = None
-        self._hold = None
         self._preset_mode = None
         self._target_temp = None
         self._target_temp_high = None
@@ -437,12 +390,6 @@ class MqttClimate(MqttEntity, ClimateEntity):
         self._feature_preset_mode = False
         self._optimistic_preset_mode = None
 
-        # CONF_SEND_IF_OFF is deprecated, support will be removed with release 2022.9
-        self._send_if_off = True
-        # AWAY and HOLD mode topics and templates are deprecated,
-        # support will be removed with release 2022.9
-        self._hold_list = []
-
         MqttEntity.__init__(self, hass, config, config_entry, discovery_data)
 
     @staticmethod
@@ -481,9 +428,6 @@ class MqttClimate(MqttEntity, ClimateEntity):
             self._preset_modes = []
         self._optimistic_preset_mode = CONF_PRESET_MODE_STATE_TOPIC not in config
         self._action = None
-        # AWAY and HOLD mode topics and templates are deprecated, support will be removed with release 2022.9
-        self._away = False
-        self._hold = None
         self._aux = False
 
         value_templates = {}
@@ -511,15 +455,6 @@ class MqttClimate(MqttEntity, ClimateEntity):
 
         self._command_templates = command_templates
 
-        # CONF_SEND_IF_OFF is deprecated, support will be removed with release 2022.9
-        if CONF_SEND_IF_OFF in config:
-            self._send_if_off = config[CONF_SEND_IF_OFF]
-
-        # AWAY and HOLD mode topics and templates are deprecated,
-        # support will be removed with release 2022.9
-        if CONF_HOLD_LIST in config:
-            self._hold_list = config[CONF_HOLD_LIST]
-
     def _prepare_subscribe_topics(self):  # noqa: C901
         """(Re)Subscribe to topics."""
         topics = {}
@@ -690,15 +625,6 @@ class MqttClimate(MqttEntity, ClimateEntity):
 
             self.async_write_ha_state()
 
-        # AWAY and HOLD mode topics and templates are deprecated, support will be removed with release 2022.9
-        @callback
-        @log_messages(self.hass, self.entity_id)
-        def handle_away_mode_received(msg):
-            """Handle receiving away mode via MQTT."""
-            handle_onoff_mode_received(msg, CONF_AWAY_MODE_STATE_TEMPLATE, "_away")
-
-        add_subscription(topics, CONF_AWAY_MODE_STATE_TOPIC, handle_away_mode_received)
-
         @callback
         @log_messages(self.hass, self.entity_id)
         def handle_aux_mode_received(msg):
@@ -707,22 +633,6 @@ class MqttClimate(MqttEntity, ClimateEntity):
 
         add_subscription(topics, CONF_AUX_STATE_TOPIC, handle_aux_mode_received)
 
-        # AWAY and HOLD mode topics and templates are deprecated, support will be removed with release 2022.9
-        @callback
-        @log_messages(self.hass, self.entity_id)
-        def handle_hold_mode_received(msg):
-            """Handle receiving hold mode via MQTT."""
-            payload = render_template(msg, CONF_HOLD_STATE_TEMPLATE)
-
-            if payload == "off":
-                payload = None
-
-            self._hold = payload
-            self._preset_mode = None
-            self.async_write_ha_state()
-
-        add_subscription(topics, CONF_HOLD_STATE_TOPIC, handle_hold_mode_received)
-
         @callback
         @log_messages(self.hass, self.entity_id)
         def handle_preset_mode_received(msg):
@@ -810,11 +720,6 @@ class MqttClimate(MqttEntity, ClimateEntity):
         """Return preset mode."""
         if self._feature_preset_mode and self._preset_mode is not None:
             return self._preset_mode
-        # AWAY and HOLD mode topics and templates are deprecated, support will be removed with release 2022.9
-        if self._hold:
-            return self._hold
-        if self._away:
-            return PRESET_AWAY
         return PRESET_NONE
 
     @property
@@ -822,17 +727,6 @@ class MqttClimate(MqttEntity, ClimateEntity):
         """Return preset modes."""
         presets = []
         presets.extend(self._preset_modes)
-
-        # AWAY and HOLD mode topics and templates are deprecated, support will be removed with release 2022.9
-        if (self._topic[CONF_AWAY_MODE_STATE_TOPIC] is not None) or (
-            self._topic[CONF_AWAY_MODE_COMMAND_TOPIC] is not None
-        ):
-            presets.append(PRESET_AWAY)
-
-        # AWAY and HOLD mode topics and templates are deprecated,
-        # support will be removed with release 2022.9
-        presets.extend(self._hold_list)
-
         if presets:
             presets.insert(0, PRESET_NONE)
 
@@ -871,10 +765,8 @@ class MqttClimate(MqttEntity, ClimateEntity):
                 # optimistic mode
                 setattr(self, attr, temp)
 
-            # CONF_SEND_IF_OFF is deprecated, support will be removed with release 2022.9
-            if self._send_if_off or self._current_operation != HVACMode.OFF:
-                payload = self._command_templates[cmnd_template](temp)
-                await self._publish(cmnd_topic, payload)
+            payload = self._command_templates[cmnd_template](temp)
+            await self._publish(cmnd_topic, payload)
 
     async def async_set_temperature(self, **kwargs: Any) -> None:
         """Set new target temperatures."""
@@ -905,17 +797,12 @@ class MqttClimate(MqttEntity, ClimateEntity):
             "_target_temp_high",
         )
 
-        # Always optimistic?
         self.async_write_ha_state()
 
     async def async_set_swing_mode(self, swing_mode: str) -> None:
         """Set new swing mode."""
-        # CONF_SEND_IF_OFF is deprecated, support will be removed with release 2022.9
-        if self._send_if_off or self._current_operation != HVACMode.OFF:
-            payload = self._command_templates[CONF_SWING_MODE_COMMAND_TEMPLATE](
-                swing_mode
-            )
-            await self._publish(CONF_SWING_MODE_COMMAND_TOPIC, payload)
+        payload = self._command_templates[CONF_SWING_MODE_COMMAND_TEMPLATE](swing_mode)
+        await self._publish(CONF_SWING_MODE_COMMAND_TOPIC, payload)
 
         if self._topic[CONF_SWING_MODE_STATE_TOPIC] is None:
             self._current_swing_mode = swing_mode
@@ -923,10 +810,8 @@ class MqttClimate(MqttEntity, ClimateEntity):
 
     async def async_set_fan_mode(self, fan_mode: str) -> None:
         """Set new target temperature."""
-        # CONF_SEND_IF_OFF is deprecated, support will be removed with release 2022.9
-        if self._send_if_off or self._current_operation != HVACMode.OFF:
-            payload = self._command_templates[CONF_FAN_MODE_COMMAND_TEMPLATE](fan_mode)
-            await self._publish(CONF_FAN_MODE_COMMAND_TOPIC, payload)
+        payload = self._command_templates[CONF_FAN_MODE_COMMAND_TEMPLATE](fan_mode)
+        await self._publish(CONF_FAN_MODE_COMMAND_TOPIC, payload)
 
         if self._topic[CONF_FAN_MODE_STATE_TOPIC] is None:
             self._current_fan_mode = fan_mode
@@ -978,49 +863,6 @@ class MqttClimate(MqttEntity, ClimateEntity):
 
             return
 
-        # Update hold or away mode: Track if we should optimistic update the state
-        optimistic_update = await self._set_away_mode(preset_mode == PRESET_AWAY)
-        hold_mode: str | None = preset_mode
-        if preset_mode in [PRESET_NONE, PRESET_AWAY]:
-            hold_mode = None
-        optimistic_update = await self._set_hold_mode(hold_mode) or optimistic_update
-
-        if optimistic_update:
-            self.async_write_ha_state()
-
-    # AWAY and HOLD mode topics and templates are deprecated, support will be removed with release 2022.9
-    async def _set_away_mode(self, state):
-        """Set away mode.
-
-        Returns if we should optimistically write the state.
-        """
-        await self._publish(
-            CONF_AWAY_MODE_COMMAND_TOPIC,
-            self._config[CONF_PAYLOAD_ON] if state else self._config[CONF_PAYLOAD_OFF],
-        )
-
-        if self._topic[CONF_AWAY_MODE_STATE_TOPIC] is not None:
-            return False
-
-        self._away = state
-        return True
-
-    async def _set_hold_mode(self, hold_mode):
-        """Set hold mode.
-
-        Returns if we should optimistically write the state.
-        """
-        payload = self._command_templates[CONF_HOLD_COMMAND_TEMPLATE](
-            hold_mode or "off"
-        )
-        await self._publish(CONF_HOLD_COMMAND_TOPIC, payload)
-
-        if self._topic[CONF_HOLD_STATE_TOPIC] is not None:
-            return False
-
-        self._hold = hold_mode
-        return True
-
     async def _set_aux_heat(self, state):
         await self._publish(
             CONF_AUX_COMMAND_TOPIC,
@@ -1069,14 +911,7 @@ class MqttClimate(MqttEntity, ClimateEntity):
         ):
             support |= ClimateEntityFeature.SWING_MODE
 
-        # AWAY and HOLD mode topics and templates are deprecated, support will be removed with release 2022.9
-        if (
-            self._feature_preset_mode
-            or (self._topic[CONF_AWAY_MODE_STATE_TOPIC] is not None)
-            or (self._topic[CONF_AWAY_MODE_COMMAND_TOPIC] is not None)
-            or (self._topic[CONF_HOLD_STATE_TOPIC] is not None)
-            or (self._topic[CONF_HOLD_COMMAND_TOPIC] is not None)
-        ):
+        if self._feature_preset_mode:
             support |= ClimateEntityFeature.PRESET_MODE
 
         if (self._topic[CONF_AUX_STATE_TOPIC] is not None) or (
