@@ -6,7 +6,6 @@ from homeassistant.const import TIME_SECONDS
 
 LOGGER = logging.getLogger(__package__)
 
-CONF_LOCAL_IP = "local_ip"
 DOMAIN = "upnp"
 BYTES_RECEIVED = "bytes_received"
 BYTES_SENT = "bytes_sent"
@@ -24,7 +23,9 @@ CONFIG_ENTRY_UDN = "udn"
 CONFIG_ENTRY_ORIGINAL_UDN = "original_udn"
 CONFIG_ENTRY_MAC_ADDRESS = "mac_address"
 CONFIG_ENTRY_LOCATION = "location"
+CONFIG_ENTRY_HOST = "host"
+IDENTIFIER_HOST = "upnp_host"
+IDENTIFIER_SERIAL_NUMBER = "upnp_serial_number"
 DEFAULT_SCAN_INTERVAL = timedelta(seconds=30).total_seconds()
 ST_IGD_V1 = "urn:schemas-upnp-org:device:InternetGatewayDevice:1"
 ST_IGD_V2 = "urn:schemas-upnp-org:device:InternetGatewayDevice:2"
-SSDP_SEARCH_TIMEOUT = 4
