@@ -15,6 +15,7 @@ from collections.abc import (
     Iterable,
     Mapping,
 )
+from contextvars import ContextVar
 import datetime
 import enum
 import functools
@@ -138,6 +139,8 @@ MAX_EXPECTED_ENTITY_IDS = 16384
 
 _LOGGER = logging.getLogger(__name__)
 
+_cv_hass: ContextVar[HomeAssistant] = ContextVar("current_entry")
+
 
 @functools.lru_cache(MAX_EXPECTED_ENTITY_IDS)
 def split_entity_id(entity_id: str) -> tuple[str, str]:
@@ -175,6 +178,18 @@ def is_callback(func: Callable[..., Any]) -> bool:
     return getattr(func, "_hass_callback", False) is True
 
 
+@callback
+def async_get_hass() -> HomeAssistant:
+    """Return the HomeAssistant instance.
+
+    Raises LookupError if no HomeAssistant instance is available.
+
+    This should be used where it's very cumbersome or downright impossible to pass
+    hass to the code which needs it.
+    """
+    return _cv_hass.get()
+
+
 @enum.unique
 class HassJobType(enum.Enum):
     """Represent a job type."""
@@ -242,6 +257,12 @@ class HomeAssistant:
     http: HomeAssistantHTTP = None  # type: ignore[assignment]
     config_entries: ConfigEntries = None  # type: ignore[assignment]
 
+    def __new__(cls) -> HomeAssistant:
+        """Set the _cv_hass context variable."""
+        hass = super().__new__(cls)
+        _cv_hass.set(hass)
+        return hass
+
     def __init__(self) -> None:
         """Initialize new Home Assistant object."""
         self.loop = asyncio.get_running_loop()
@@ -816,7 +837,7 @@ class Event:
 class _FilterableJob(NamedTuple):
     """Event listener job to be executed with optional filter."""
 
-    job: HassJob[[Event], None | Awaitable[None]]
+    job: HassJob[[Event], Coroutine[Any, Any, None] | None]
     event_filter: Callable[[Event], bool] | None
     run_immediately: bool
 
@@ -907,7 +928,7 @@ class EventBus:
     def listen(
         self,
         event_type: str,
-        listener: Callable[[Event], None | Awaitable[None]],
+        listener: Callable[[Event], Coroutine[Any, Any, None] | None],
     ) -> CALLBACK_TYPE:
         """Listen for all events or events of a specific type.
 
@@ -928,7 +949,7 @@ class EventBus:
     def async_listen(
         self,
         event_type: str,
-        listener: Callable[[Event], None | Awaitable[None]],
+        listener: Callable[[Event], Coroutine[Any, Any, None] | None],
         event_filter: Callable[[Event], bool] | None = None,
         run_immediately: bool = False,
     ) -> CALLBACK_TYPE:
@@ -968,7 +989,9 @@ class EventBus:
         return remove_listener
 
     def listen_once(
-        self, event_type: str, listener: Callable[[Event], None | Awaitable[None]]
+        self,
+        event_type: str,
+        listener: Callable[[Event], Coroutine[Any, Any, None] | None],
     ) -> CALLBACK_TYPE:
         """Listen once for event of a specific type.
 
@@ -989,7 +1012,9 @@ class EventBus:
 
     @callback
     def async_listen_once(
-        self, event_type: str, listener: Callable[[Event], None | Awaitable[None]]
+        self,
+        event_type: str,
+        listener: Callable[[Event], Coroutine[Any, Any, None] | None],
     ) -> CALLBACK_TYPE:
         """Listen once for event of a specific type.
 
@@ -1463,7 +1488,7 @@ class Service:
 
     def __init__(
         self,
-        func: Callable[[ServiceCall], None | Awaitable[None]],
+        func: Callable[[ServiceCall], Coroutine[Any, Any, None] | None],
         schema: vol.Schema | None,
         context: Context | None = None,
     ) -> None:
@@ -1533,7 +1558,7 @@ class ServiceRegistry:
         self,
         domain: str,
         service: str,
-        service_func: Callable[[ServiceCall], Awaitable[None] | None],
+        service_func: Callable[[ServiceCall], Coroutine[Any, Any, None] | None],
         schema: vol.Schema | None = None,
     ) -> None:
         """
@@ -1550,7 +1575,7 @@ class ServiceRegistry:
         self,
         domain: str,
         service: str,
-        service_func: Callable[[ServiceCall], Awaitable[None] | None],
+        service_func: Callable[[ServiceCall], Coroutine[Any, Any, None] | None],
         schema: vol.Schema | None = None,
     ) -> None:
         """
@@ -1942,7 +1967,7 @@ class Config:
         # pylint: disable=import-outside-toplevel
         from .helpers.storage import Store
 
-        store = Store(
+        store = Store[dict[str, Any]](
             self.hass,
             CORE_STORAGE_VERSION,
             CORE_STORAGE_KEY,
@@ -1950,7 +1975,7 @@ class Config:
             atomic_writes=True,
         )
 
-        if not (data := await store.async_load()) or not isinstance(data, dict):
+        if not (data := await store.async_load()):
             return
 
         # In 2021.9 we fixed validation to disallow a path (because that's never correct)
@@ -1998,7 +2023,7 @@ class Config:
             "currency": self.currency,
         }
 
-        store = Store(
+        store: Store[dict[str, Any]] = Store(
             self.hass,
             CORE_STORAGE_VERSION,
             CORE_STORAGE_KEY,
